@@ -25,6 +25,11 @@ from oauth2client import client
 from oauth2client import tools
 from oauth2client import file
 
+try:
+	import argparse
+	flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args()
+except ImportError:
+	flags = None
 
 def read_connection_data_from_external_file(filepath, separator="="):
 	"""Reads SQL server connection information from an external file.
@@ -275,7 +280,7 @@ def get_files_from_drive(drive_service, name=None, substring_name=None, mime_typ
 		if mime_type == "folder":
 			query_list.append("mimeType = 'application/vnd.google-apps.folder'")
 		elif mime_type == "file":
-			query_list.append("mimeType = 'application/vnd.google-apps.file")
+			query_list.append("mimeType = 'application/vnd.google-apps.file'")
 		else:
 			raise ValueError("'mime_type' argument must be 'folder' or 'file'.")
 			exit(0)
@@ -320,7 +325,7 @@ def get_files_from_drive(drive_service, name=None, substring_name=None, mime_typ
 			if not page_token:
 				break
 		except HttpError as e:
-			print('An error occurred: {}'.format(a))
+			print('An error occurred: {}'.format(e))
 			break
 
 	return result
@@ -516,8 +521,4 @@ def insert_file_into_folder(drive_service, folder_id, file_id):
 	drive_service.files().update(fileId=file_id, addParents=folder_id, fields='id, parents').execute()
 
 if __name__ == '__main__':
-	try:
-		import argparse
-		flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args()
-	except ImportError:
-		flags = None
+	main()
